#include "template.cpp"


struct bigInt{
    string v;
    bool sign;
    int base;

    bigInt(string n="0", bool s=0, int b=10): v(n), sign(s), base(b) {
        reverse(v.begin(),v.end());
        if(v[v.size()-1]=='-'){
            sign=1;
            v.resize(v.size()-1);
        }
    }
    string baseConversion(int newbase){
        long long n=0, k=1;
        for(int i=v.size()-1;i>=0;i--){
            if(isdigit(v[i])) n+=(v[i]-'0')*k;
            else n+=(v[i]-'A'+10)*k;
            k*=base;
        }
        base=newbase;
        v.resize(0);
        while(n>0){
            k=n%base;
            if(k<10) v.push_back(k+'0');
            else v.push_back(k+'A'-10);
            n/=base;
        }
        reverse(v.begin(),v.end());
        return v;
    }

    bigInt operator+(bigInt n){
        bigInt ans;
        int carry=0;
        ans.v.resize(0);
        fr(i,0,max(v.size(),n.v.size())){
            ans.v.push_back(carry+'0');
            if(i<v.size()) ans.v[i]+=(v[i]-'0')*(sign?-1:1);
            if(i<n.v.size()) ans.v[i]+=(n.v[i]-'0')*(n.sign?-1:1);
            carry=floor((ans.v[i]-'0')/10.0);
            ans.v[i]-=10*carry;
        }
        if(carry>0) ans.v.push_back(carry+'0');
        if(carry<0){
            if(carry<-1) ans.v.push_back(carry+'0'+10);
            bigInt m;
            m.v.resize(ans.v.size(),'0');
            m.v.push_back(1+'0');
            ans.sign=1;
            ans=m+ans;
            ans.sign=1;
        }
        for(int i=ans.v.size()-1;ans.v[i]=='0'&&i>0;i--) ans.v.resize(ans.v.size()-1);
        return ans;
    }
    bigInt operator-(bigInt n){
        n.sign=!n.sign;
        return (*this)+n;
    }
    bigInt operator*(bigInt n){
        bigInt ans;
        fr(i,0,v.size()){
            fr(j,0,v[i]-'0'){
                ans=ans+n;
            }
            n.v.insert(n.v.begin(),'0');
        }
        for(int i=ans.v.size()-1;ans.v[i]=='0'&&i>0;i--) ans.v.resize(ans.v.size()-1);
        ans.sign=sign^n.sign;
        if(ans.v=="0") ans.sign=0;
        return ans;
    }
    bigInt operator/(bigInt n){
        bigInt q,r;
        for(int i=v.size()-1;i>=0;i--){

        }
    }
};

istream &operator>>(istream &is, bigInt &n){
    string s;
    is>>s;
    n=bigInt(s);
    return is;
}

ostream &operator<<(ostream &os, bigInt n){
    if(n.sign) os<<'-';
    fr(i,0,n.v.size()) os<<n.v[n.v.size()-i-1];
    return os;
}

typedef vector< vector<long long> > mtx;


long long exponentiation(long long n, int p, long long mod=INF){    //O(log(p))
    long long ans=1;
    while(p>0){
        if(p%2) ans=(ans*n)%mod;
        n=(n*n)%mod;
        p/=2;
    }
    return ans;
}

long long factorial(int n){    //O(n)
    long long ans=1;
    fr(i,1,n+1) ans=(ans*i)%INF;
    return ans;
}

long long fibonacci(int n){    //O(log(n))
    long long ans0=0, ans1=1, k0=0, k1=1, tmp;
    while(n>0){
        if(n%2){
            tmp = (ans0*k1)%INF;
            ans0 = (ans1*k1 + ans0*k0 + tmp)%INF;
            ans1 = (ans1*k0 + tmp)%INF;
        }
        tmp = (k1*k1)%INF;
        k1 = (2*k0*k1 + tmp)%INF;
        k0 = (k0*k0 + tmp)%INF;
        n/=2;
    }
    return ans0;
}

vi zeckendorf(int n){    //O(log(n))
    vi v;
    int f1=0, f2=1;
    while(f2<=n){
        f2+=f1;
        f1=f2-f1;
    }
    v.push_back(f1);
    n-=f1;
    while(n>0){
        while(f1>n){
            f1=f2-f1;
            f2-=f1;
        }
        v.push_back(f1);
        n-=f1;
    }
    return v;
}

long long combination(int n, int k){    //O(k)
    long long ans=1;
    if(k>n/2) k=n-k;
    fr(i,1,k+1){
        ans*=n;
        ans/=i;
        n--;
    }
    return ans;
}

long long combMod(int n, int k){    //O(k^2)
    long long ans=1;
    vi v;
    if(k>n/2) k=n-k;
    fr(i,0,k) v.push_back(n-i);
    for(int i=k;i>0;i--)
        fr(j,0,k)
            if(!(v[j]%i)){
                v[j]/=i;
                break;
            }
    fr(i,0,k) ans=(ans*v[i])%INF;
    return ans;
}

long long catalan(int n){    //O(n) - Monotonic paths in nn grid not passing above the diagonal
    long long ans=combination(2*n,n);
    ans/=n+1;
    return ans;
}

long long eulerian(int n, int k){    //O(n^2) - Permutations of n with k elements greater than the previous
    mtx nmbrs;
    nmbrs.resize(n+1);
    fr(i,1,n+1){
        nmbrs[i].resize(i);
        nmbrs[i][0]=1;
        nmbrs[i][i-1]=1;
    }
    fr(i,2,n+1){
        fr(j,1,i-1){
            nmbrs[i][j] = (j+1)*nmbrs[i-1][j] + (i-j)*nmbrs[i-1][j-1];
        }
    }
    return nmbrs[n][k];
}

long long stirlingFst(int n, int k){    //O(n^2) - Permutations of n with k cycles
    mtx nmbrs;
    nmbrs.resize(n+1);
    fr(i,0,n+1){
        nmbrs[i].resize(i+1);
        nmbrs[i][0]=0;
        nmbrs[i][i]=1;
    }
    fr(i,1,n+1){
        fr(j,1,i){
            nmbrs[i][j] = (i-1)*nmbrs[i-1][j] + nmbrs[i-1][j-1];
        }
    }
    return nmbrs[n][k];
}

long long stirlingSnd(int n, int k){    //O(n^2) - Partition n itens in k sets
    mtx nmbrs;
    nmbrs.resize(n+1);
    fr(i,0,n+1){
        nmbrs[i].resize(i+1);
        nmbrs[i][0]=0;
        nmbrs[i][i]=1;
    }
    fr(i,1,n+1){
        fr(j,1,i){
            nmbrs[i][j] = j*nmbrs[i-1][j] + nmbrs[i-1][j-1];
        }
    }
    return nmbrs[n][k];
}

long long intPart(int n, int k){    //O(n^2) - Partition n similar itens in k sets
    mtx nmbrs;
    nmbrs.resize(n+1);
    fr(i,1,n+1){
        nmbrs[i].resize(n+1,0);
        nmbrs[i][1]=1;
        nmbrs[i][i]=1;
    }
    fr(i,1,n+1){
        fr(j,2,i){
            nmbrs[i][j] = nmbrs[i-j][j] + nmbrs[i-1][j-1];
        }
    }
    return nmbrs[n][k];
}

//long long burnside(){}

long long josephus(int n, int k){    //O(k*log(n))
    if(n==1) return 0;
    if(k==1) return n-1;
    if(k>n) return (josephus(n-1,k)+k)%n;
    int j=josephus(n-n/k,k)-(n%k);
    if(j<0) j+=n;
    else j+=j/(k-1);
    return j;
}


int main(){
    int n, k;
    cin>>n>>k;

    cout<<"Power: "<<exponentiation(n,k)<<endl;
    cout<<"Factorial: "<<factorial(n)<<endl;
    cout<<"Fibonacci: "<<fibonacci(n)<<endl;
    cout<<"Zeckendorf:"<<zeckendorf(n)<<endl;
    cout<<"Combination: "<<combination(n,k)<<endl;
    cout<<"Modular Combination: "<<combMod(n,k)<<endl;
    cout<<"Catalan: "<<catalan(n)<<endl;
    cout<<"Eulerian: "<<eulerian(n,k)<<endl;
    cout<<"Stirling 1st: "<<stirlingFst(n,k)<<endl;
    cout<<"Stirling 2nd: "<<stirlingSnd(n,k)<<endl;
    cout<<"Integer Partitions: "<<intPart(n,k)<<endl;
    cout<<"Josephus: "<<josephus(n,k)<<endl;
}
