#include "template.cpp"


int cmp(double a, double b=0){
    if(fabs(a-b)<EPS) return 0;
    return (a<b)?-1:1;
}

struct point{
    double x, y;
    point(double x=0, double y=0): x(x), y(y) {}
    bool operator==(point p){return !cmp(x,p.x)&&!cmp(y,p.y);}
    point operator+(point p){return point(x+p.x, y+p.y);}
    point operator-(point p){return point(x-p.x, y-p.y);}
    point operator*(double c){return point(x*c, y*c);}
    point operator/(double c){return point(x/c, y/c);}
    double operator%(point p){return x*p.y-y*p.x;}
    double operator!(){return sqrt(x*x+y*y);}
    bool inBox(point mx, point mn){
        if(cmp(mx.x,mn.x)<0) swap(mx.x,mn.x);
        if(cmp(mx.y,mn.y)<0) swap(mx.y,mn.y);
        return !(cmp(x,mn.x)<0||cmp(x,mx.x)>0||cmp(y,mn.y)<0||cmp(y,mx.y)>0);
    }
};
typedef point pt;

ostream &operator<<(ostream &os, pt p){
    os<<'('<<p.x<<','<<p.y<<')';
    return os;
}

bool operator<(pt p, pt q){return cmp(p.x,q.x)<0||(!cmp(p.x,q.x)&&cmp(p.y,q.y)<0);}
int turn(pt p, pt q, pt r){return cmp((r.x-q.x)*(p.y-q.y),(r.y-q.y)*(p.x-q.x));}
int interSeg(pt r1, pt r2, pt s1, pt s2){
    int a=turn(r1,r2,s1)*turn(r1,r2,s1), b=turn(s1,s2,r1)*turn(s1,s2,r1);
    if(a==b==0) return -(r1.inBox(s1,s2)||r2.inBox(s1,s2)||s1.inBox(r1,r2)||s2.inBox(r1,r2));
    return a<=0&&b<=0;
}

struct line{
    double a, b, c;
    line(double a=0, double b=0, double c=0): a(a), b(b), c(c) {}
    bool operator==(line l){return !cmp(a/l.a,b/l.b)&&!cmp(a/l.a,c/l.c);}
    line para(pt p=pt()){return line(a,b,-a*p.x-b*p.y);}
    line perp(pt p=pt()){return line(b,-a,a*p.y-b*p.x);}
    pt inter(line l){return pt((b*l.c-l.b*c)/(l.b*a-b*l.a),(a*l.c-l.a*c)/(l.a*b-a*l.b));}
    bool onLine(pt p){return !cmp(a*p.x+b*p.y+c);}
};

line slope(pt p){return line(p.y,-p.x);}
line toLine(pt p, pt q){return slope(p-q).para(p);}
pt interPt(pt r1, pt r2, pt s1, pt s2){return toLine(r1,r2).inter(toLine(s1,s2));}

struct polygon{
    vector<pt> v;
    polygon(vector<pt> v=vector<pt>()): v(v) {}
    void operator+=(pt p){v.push_back(p);}
    void operator--(){v.pop_back();}
    pt now(){return v[v.size()-1];}
    pt prev(){return v[v.size()-2];}
    pt operator[](int i){return v[i%v.size()];}
    double peri(){    //O(V)
        double peri=0;
        fr(i,0,v.size())
            peri+=!(pl[i]-pl[i+1]);
        return peri;
    }
    double area(){    //O(V)
        double area=0;
        fr(i,0,v.size())
            area+=pl[i]%pl[i+1];
        return area/2;
    }
    bool isConvex(bool b=0){    //O(V)
        fr(i,0,v.size()){
            int t=turn(pl[i],pl[i+1],pl[i+2]);
            if(t<0||!(b||t)) return 0;
        }
        return 1;
    }
    bool inConvex(pt p, bool b=0){    //O(V)
        fr(i,0,v.size()){
            int t=turn(pl[i],pl[i+1],p);
            if(t<0||!(b||t)) return 0;
        }
        return 1;
    }
    bool inConcave(pt p, bool b=0){    //O(V)
        pt mp=pl[0];
        fr(i,0,v.size()){
            if(!turn(pl[i],pl[i+1],p)&&p.inBox(pl[i],pl[i+1])) return b;
            mp=min(mp,pl[i]);
        }
        mp.x--;
        int cnt=0,k=0;
        while(!turn(p,mp,pl[k])) k++;
        fr(i,k,v.size()+k){
            int j=1;
            while(!turn(p,mp,pl[i+j])) j++;
            if(interSeg(p,mp,pl[i],pl[i+j])) cnt++;
        }
        return cnt%2;
    }
    polygon crop(pt p, pt q){    //O(V)
        polygon cut;
        bool one=1, zero=0;
        vector<bool> t(v.size());
        fr(i,0,v.size()){
            if(turn(p,q,pl[i])>0) t[i]=1;
            one&=t[i];
            zero|=t[i];
        }
        if(one) return pl;
        if(zero) return cut;
        int i=0;
        for(;t[i]>=t[i+1]&&i<v.size();i++);
        cut+=interPt(p,q,pl[i],pl[i+1]);
        for(;t[i]<=t[i+1];i++) cut+=pl[i+1];
        cut+=interPt(p,q,pl[i],pl[i+1]);
        return cut;
    }
};

struct ball{
    double r;
    point c;
    ball(double r=0, point c=point()): r(r), c(c) {}
    double peri(){return 2*PI*r;}
    double area(){return PI*r*r;}
    double sup(){return 4*PI*r*r;}
    double vol(){return 4*PI*r*r*r/3;}
    double greatCD(pt p, pt q){return r*(sin(p.y)*sin(q.y)+cos(p.y)*cos(q.y)*cos(p.x-q.x));}
};

pt pvt;
bool angCmp(pt a, pt b){
    int t=turn(pvt,a,b);
    if(t) return t<0?0:1;
    return cmp(!(pvt-a),!(pvt-b))<0;
}

polygon convexHull(vector<pt> ps){    //O(V*log(V))
    int n=ps.size(), sp=0;
    polygon ch;
    ps.resize(distance(ps.begin(),unique(ps.begin(),ps.end())));
    fr(i,1,n){
        if(ps[i]<ps[sp]) sp=i;
    }
    pvt=ps[sp];
    swap(ps[0],ps[sp]);
    sort(++ps.begin(),ps.end(),angCmp);
    ch+=ps[n-1];
    ch+=ps[0];
    fr(i,1,n){
        while(turn(ch.prev(),ch.now(),ps[i])<=0) --ch;
        ch+=ps[i];
    }
    --ch;
    return ch;
}

double closestPair(vector<pt> ps){    //O(V^2)
    double d=INF;
    sort(ps.begin(),ps.end());
    fr(i,0,ps.size()){
        fr(j,i+1,ps.size()){
            if(cmp(d,ps[j].x-ps[i].x)<0) break;
            d=min(d,!(ps[j]-ps[i]));
        }
    }
    return d;
}

vector<pt> interpts(polygon p, polygon q){    //O(V^2)
    vector<pt> ps;
    fr(i,0,p.v.size()){
        fr(j,0,q.v.size()){
            if(interSeg(p[i],p[i+1],q[i],q[i+1])>0){
                ps.push_back(interPt(p[i],p[i+1],q[i],q[i+1]));
            }
        }
    }
    sort(ps.begin(),ps.end());
    ps.resize(distance(ps.begin(),unique(ps.begin(),ps.end())));
    return ps;
}

polygon interPoly(polygon p, polygon q){    //O(V^2)
    vector<pt> ps=interpts(p,q);
    fr(i,0,p.v.size()){
        if(q.inConvex(p[i])) ps.push_back(p[i]);
    }
    fr(i,0,q.v.size()){
        if(p.inConvex(q[i])) ps.push_back(q[i]);
    }
    return convexHull(ps);
}

vector<polygon> triangulate(polygon p){    //O(V^2)
    vector<polygon> vt;
    bool ear;
    for(int i=0;p.v.size()>2;i++){
        polygon t(vector<pt>(3));
        t.v[0]=p[i];
        t.v[1]=p[i+1];
        t.v[2]=p[i+2];
        if(t.isConvex()){
            ear=1;
            fr(j,0,p.v.size()){
                if(j!=i&&t.inConvex(p[j])) ear=0;
            }
            if(ear){
                vt.push_back(t);
                p.v.erase(p.v.begin()+((i+1)%p.v.size()));
                i--;
            }
        }
    }
    return vt;
}

double bisection(double (*f)(double), double ans, double hi, double lo){
	double x;
	while(cmp(hi,lo)){
		x=(lo+hi)/2;
		if(f(x)>ans) hi=x;
		else lo=x;
	}
	return x;
}

//Henron(triangle): A=sqrt(s*(s-a)*(s-b)*(s-c));
//InnerCircle(triangle): r=A/s;
//OuterCircle(triangle): r=a*b*c/(4*A);
//Pick(lattice): A=I+B/2-1;

int main(){
    int a,b,c;

    stringstream ss;
    string s1;
    while(1){
        getline(cin,s1);
        if(s1.empty()) break;
        ss.str(s1);
        ss>>a>>b>>c;
        ss.seekg(0,ss.beg);
    }

    char s2[20];
    while(1){
        fgets(s2,20,stdin);
        if(s2[0]=='\n') break;
        sscanf(s2,"%d %d %d",&a,&b,&c);
    }
}
