#include "template.cpp"


struct djSets{
    vector<int> pset;
    int qnt;
    djSets(int n){pset.resize(n); fr(i,0,n) pset[i]=i; qnt=n;}
    int findSet(int a){return (pset[a]==a)?a:(pset[a]=findSet(pset[a]));}
    bool isSameSet(int a, int b){return findSet(a)==findSet(b);}
    void unionSet(int a, int b){if(!isSameSet(a,b)){pset[findSet(a)]=findSet(b); qnt--;}}
};

struct edge{
    int from, to, wght;
    edge(int u, int v, int w): from(u), to(v), wght(w) {}
    bool operator>(edge e){return wght>e.wght;}
    bool operator<(edge e){return wght<e.wght;}
    bool operator()(edge e1, edge e2){return e1>e2;}
};
typedef vector<edge> ve;

int V, E;
vector<vi> AdjMtx;
vector<ve> AdjLst;
priority_queue< edge, ve, edge > EdgeLst;
vi palette(V,0);
vector<bool> artPoint(V,0);
vector< vector<bool> > bridge(V);


vi DFS(int s, int color=0){    //O(V+E)
    int ord=0;
    vi num(V,-1);
    num[s]=0;
    stack<ii> stk;
    stk.push(ii(s,0));
    while(!stk.empty()){
        int u=stk.top().first, k=stk.top().second;
        stk.pop();
        fr(i,k,AdjLst[u].size()){
            v=AdjLst[u][i].to;
            if(num[v]<0){
                stk.push(ii(u,i));
                parent[v]=u;
                palette(v)=color;
                num[u=v]=low[v]=ord++;
                i=-1;
            }
        }
    }
    return num;
}

vi BFS(int s, int color=0){    //O(V+E)
    vi num(V,-1);
    num[s]=0;
    queue<int> que;
    que.push(s);
    while(!que.empty()){
        int u=que.front();
        que.pop();
        fr(i,0,AdjLst[u].size()){
            v=AdjLst[u][i].to;
            if(num[v]<0){
                que.push(v);
                palette(v)=color;
                num[v]=num[u]+1;
            }
        }
    }
    return num;
}

vi SCC(int s, int color=0){    //O(V+E)
    int ord=0;
    vi num(V,-1), low(V,-1), parent(V,-1);
    num[s]=0;
    stack<ii> stk;
    stk.push(ii(s,0));
    while(!stk.empty()){
        int u=stk.top().first, k=stk.top().second;
        stk.pop();
        fr(i,k,AdjLst[u].size()){
            v=AdjLst[u][i].to;
            if(num[v]<0){
                stk.push(ii(u,i));
                parent[v]=u;
                palette(v)=color;
                num[u=v]=low[v]=ord++;
                i=-1;
            }
            else{
                if(v!=parent[u]) low[u]=min(low[u],num[v]);
                if(num[u]<num[v]) low[u]=min(low[u],low[v]);
                if(num[u]<=low[v]) artPoint[u]=1;
                if(num[u]<low[v]) bridge[u][v]=bridge[v][u]=1;
            }
        }
    }
    return num;
}

pair<int,ve> MST_Kruskal(){    //O(E*log(E))
    int cost=0;
    ve mst;
    djSets dst(V);
    priority_queue< edge, ve, edge > pq(EdgeLst);
    while(dst.qnt>1){
        int u=pq.top().from, v=pq.top().to;
        if(!dst.isSameSet(u,v)){
            cost+=pq.top().wght;
            dst.unionSet(u,v);
            mst.push_back(pq.top());
        }
        pq.pop();
    }
    return make_pair(cost,mst);
}

pair<int,ve> MST_Prim(){    //O((V+E)*log(V))
    int cost=0;
    ve mst;
    vi dist(V,INF);
    dist[s]=0;
    priority_queue< edge, ve, edge > pq;
    pq.push(edge(s,0,s));
    while(!pq.empty()){
        edge e=pq.top();
        int d=e.wght, u=e.to;
        pq.pop();
        if(d==dist[u]){
            cost+=d;
            if(u!=s) mst.push_back(e);
            dist[u]=0;
            fr(i,0,AdjLst[u].size()){
                int v=AdjLst[u][i].to, w=AdjLst[u][i].wght;
                if(w<dist[v]){
                    dist[v]=w;
                    pq.push(edge(u,v,w));
                }
            }
        }
    }
    return make_pair(cost,mst);
}

vi SSSP_Dijkstra(int s){    //O((V+E)*log(V))
    vi dist(V,INF);
    dist[s]=0;
    priority_queue< ii, vii, greater<ii> > pq;
    pq.push(ii(0,s));
    while(!pq.empty()){
        int d=pq.top().first, u=pq.top().second;
        pq.pop();
        if(d==dist[u]){
            fr(i,0,AdjLst[u].size()){
                int v=AdjLst[u][i].to, w=AdjLst[u][i].wght;
                if(dist[u]+w<dist[v]){
                    dist[v]=dist[u]+w;
                    pq.push(ii(dist[v],v));
                }
            }
        }
    }
    return dist;
}

vi SSSP_BellmanFord(int s){    //O(V*E)
    vi dist(V,INF);
    dist[s]=0;
    fr(k,0,V){
        fr(u,0,V){
            fr(i,0,AdjLst[u].size()){
                int v=AdjLst[u][i].to, w=AdjLst[u][i].wght;
                dist[v]=min(dist[v], dist[u]+w);
            }
        }
    }
    return dist;
}

vector<vi> APSP_FloydWarshall(){    //O(V^3)
    vector<vi> dist(AdjMtx);
    fr(k,0,V){
        fr(i,0,V){
            fr(j,0,V){
                dist[i][j]=min(dist[i][j], dist[i][k]+dist[k][j]);
            }
        }
    }
    return dist;
}

pair<int,ve> MF_EdmondsKarp(int s, int t){
    int f, maxFlow=0;
    ve minCut;
    vector<vi> residue(AdjMtx);
    while(1){
        vi num(V,-1), p(V,-1);
        num[s]=0;
        queue<int> que;
        que.push(s);
        while(!que.empty()){
            int u=que.front();
            que.pop();
            if(u==t) break;
            fr(i,0,AdjLst[u].size()){
                v=AdjLst[u][i].to;
                if(residue[u][v]&&num[v]<0){
                    que.push(v);
                    num[v]=num[u]+1;
                    p[v]=u;
                }
            }
        }
        if(p[t]==-1) break;
        f=INF;
        stack<int> stk;
        stk.push(t);
        while(stk.top()!=s){
            int u=stk.top();
            f=min(f,residue[p[u]][u]);
            stk.push(p[u]);
        }
        stk.pop();
        while(!stk.empty()){
            int u=stk.top();
            residue[p[u]][u]-=f;
            residue[u][p[u]]+=f;
            stk.pop();
        }
        maxFlow+=f;
    }
    fr(u,0,V){
        fr(i,0,AdjLst[u].size()){
            v=AdjLst[u][i].to;
            if(!residue[u][v]) minCut.push_back(AdjLst[u]);
        }
    }
    return make_pair(maxFlow,minCut);
}


pair<int,ve> SndMST(){
    int mincost=INF;
    vi mst;
    ve edges(EdgeLst), minst;
    sort(edges.begin(),edges.end(),edge);
    fr(it,0,1){
        djSets dst(V);
        queue<edge> pq(edges);
        for(int i=0;dst.qnt>1;i++){
            int u=pq.top().from, v=pq.top().to;
            if(!dst.isSameSet(u,v)){
                dst.unionSet(u,v);
                mst.push_back(i);
            }
            pq.pop();
        }
    }
    fr(i,0,mst.size()){
        int cost=0, m=edges[i].wght;
        edges[i].wght=INF;
        ve st;
        djSets dst(V);
        queue<edge> pq(edges);
        while(dst.qnt>1){
            int u=pq.top().from, v=pq.top().to;
            if(!dst.isSameSet(u,v)){
                cost+=pq.top().wght;
                dst.unionSet(u,v);
                st.push_back(pq.top());
            }
            pq.pop();
        }
        if(cost<mincost){
            mincost=cost;
            minst=st;
        }
        edges[i].wght=m;
    }
    return make_pair(mincost,minst);
}

bool negativeCycle(int s){
    bool nc=0;
    SSSP_BellmanFord(s);
    fr(u,0,V){
        fr(i,0,AdjLst[u].size()){
            int v=AdjLst[u][i].to, w=AdjLst[u][i].wght;
            if(dist[v]>dist[u]+w) nc=1;
        }
    }
    return nc;
}

pair<int,ve> MCMF(int s, int t){
    int f, maxFlow=0;
    ve minCut;
    vector<vi> residue(AdjMtx);
    while(1){
        vi dist(V,INF), p(V,-1);
        dist[s]=0;
        fr(k,0,V){
            fr(u,0,V){
                fr(i,0,AdjLst[u].size()){
                    int v=AdjLst[u][i].to, w=AdjLst[u][i].wght;
                    if(residue[u][v]&&dist[v]<dist[u]+w){
                        dist[v]=dist[u]+w;
                        p[v]=u;
                    }
                }
            }
        }

        if(p[t]==-1) break;
        f=INF;
        stack<int> stk;
        stk.push(t);
        while(stk.top()!=s){
            int u=stk.top();
            f=min(f,residue[p[u]][u]);
            stk.push(p[u]);
        }
        stk.pop();
        while(!stk.empty()){
            int u=stk.top();
            residue[p[u]][u]-=f;
            residue[u][p[u]]+=f;
            stk.pop();
        }
        maxFlow+=f;
    }
    fr(u,0,V){
        fr(i,0,AdjLst[u].size()){
            v=AdjLst[u][i].to;
            if(!residue[u][v]) minCut.push_back(AdjLst[u]);
        }
    }
    return make_pair(maxFlow,minCut);
}

//2sat

int main(){
    int s, t;
    edge ha, ho;
    //cin>>ha.from>>ha.wght>>ha.to;
    //cin>>ho.from>>ho.wght>>ho.to;
    //cout<< (ha>ho) << (ha<ho) <<endl;
    priority_queue< edge, ve, hiho > pq;
    fr(i,0,5){
        cin>>ha.from>>ha.wght>>ha.to;
        pq.push(ha);
    }
    fr(i,0,5){
        cout<<pq.top().from<<' '<<pq.top().wght<<' '<<pq.top().to<<endl;
        pq.pop();
    }
}
