#include "template.cpp"


vector<int> primes;

ostream &operator<<(ostream &os, pair<int,int> p){
    os<<p.first<<ends<<p.second;
    return os;
}

ostream &operator<<(ostream &os, pair< vector<int>,vector<int> > pv){
    fr(i,0,pv.first.size()) os<<ends<<pv.first[i]<<'^'<<pv.second[i];
    return os;
}

struct polynomial{
    int n;
    vector<int> v;
    polynomial(int n=0): n(n), v(n+1) {}
    polynomial operator+(polynomial a){    //O(n)
        polynomial b(max(n,a.n));
        fr(i,0,max(n,a.n)+1){
            if(i<=n) b.v[i]+=v[i];
            if(i<=a.n) b.v[i]+=a.v[i];
        }
        return b;
    }
    polynomial operator-(polynomial a){    //O(n)
        polynomial b(max(n,a.n));
        fr(i,0,max(n,a.n)+1){
            if(i<=n) b.v[i]+=v[i];
            if(i<=a.n) b.v[i]-=a.v[i];
        }
        return b;
    }
    polynomial operator*(polynomial a){    //O(n^2)
        polynomial b(n+a.n);
        fr(i,0,n+1){
            fr(j,0,a.n+1){
                b.v[i+j]+=v[i]*a.v[j];
            }
        }
        return b;
    }
    long long result(int x){    //O(n)
        long long ans=v[n];
        fr(i,0,n){
            ans=ans*x+v[n-1-i];
        }
        return ans;
    }
};

long long exponentiation(long long n, int p, long long mod=INF){    //O(log(p))
    long long ans=1;
    while(p>0){
        if(p%2) ans=(ans*n)%mod;
        n=(n*n)%mod;
        p/=2;
    }
    return ans;
}

void sieve(int n){    //O(n*log(log(n)))
    vector<bool> bs(++n,1);
    primes.resize(0);
    bs[0]=bs[1]=0;
    fr(i,2,n) if(bs[i]){
        for(int j=i*i;j<n;j+=i) bs[j]=0;
        primes.push_back(i);
    }
}

bool isPrime(int n){    //O(sqrt(n)/ln(sqrt(n)))
    fr(i,0,primes.size()) if(!(n%primes[i])) return 0;
    return 1;
}

pair< vector<int>,vector<int> > primeFactors(int n){    //O(sqrt(n)/ln(sqrt(n)))
    vector<int> factors, powers;
    int i=0;
    for(int pf=primes[i];pf*pf<=n;pf=primes[++i]){
        if(!(n%pf)){
            n/=pf;
            factors.push_back(pf);
            powers.push_back(1);
        }
        while(!(n%pf)){
            n/=pf;
            powers.back()++;
        }
    }
    if(n!=1) factors.push_back(n), powers.push_back(1);
    return make_pair(factors,powers);
}

long long coprimes(int n){    //O(sqrt(n)/ln(sqrt(n)))
    int ans=n;
    vector<int> pf = primeFactors(n).first;
    fr(i,0,pf.size()) ans-=ans/pf[i];
    return ans;
}

bool carmichael(int n){    //O(sqrt(n)*log(n))
    int a, prime=1, sq=sqrt(n);
    for(a=2;a<n;a++){
        if(!(n%a)) prime=0;
        if(a>sq&&prime) break;
        if(a!=exponentiation(a,n,n)) break;
    }
    return (a==n&&!prime);
}

long long zeros(int n, int f){    //O(log(n))
    long long ans=0, d=f;
    while(d<=n){
        ans+=n/d;
        d*=f;
    }
    return ans;
}

long long gcd(int a, int b){    //O(log(b))
    while(b>0){
        a%=b;
        swap(a,b);
    }
    return a;
}

long long lcm(int a, int b){    //O(log(b))
    return (a*b)/gcd(a,b);
}

pair<int,int> euclid(int a, int b){    //O(log(b))
    if(b==0) return make_pair(1,0);
    pair<int,int> p=euclid(b,a%b);
    long long x=p.first, y=p.second;
    return make_pair(y,x-y*(a/b));
}

pair<int,int> diophantine(int a, int b, int c){    //O(log(b))
    int d=gcd(a,b);
    if(c%d) return make_pair(0,0);
    pair<int,int> p=euclid(a,b);
    long long x=p.first, y=p.second;
    return make_pair(x*(c/d),y*(c/d));
}

long long CRT(vector< pair<int,int> > cngr){    //O(log(m))
    long long m=1, ans=0;
    fr(i,0,cngr.size()) m*=cngr[i].second;
    fr(i,0,cngr.size()){
        int a=cngr[i].first, n=cngr[i].second;
        int z=euclid(m/n,n).first;
        if(z<0) z+=n;
        ans+=a*(m/n)*z;
    }
    return ans%m;
}

struct rational{
    int a, b;
    rational(int a=0, int b=1): a(a), b(b) {}
    rational operator+(rational r){return rational(a*r.b+r.a*b, b*r.b);}
    rational operator-(rational r){return rational(a*r.b-r.a*b, b*r.b);}
    rational operator*(rational r){return rational(a*r.a, b*r.b);}
    rational operator/(rational r){return rational(a*r.b, b*r.a);}
    bool operator==(rational r){return a*r.b==b*r.a;}
    bool operator<(rational r){return a*r.b<b*r.a;}
    double real(){return (double)a/b;}
    rational reduce(){    //O(log(b))
        int d=gcd(a,b);
        a/=d, b/=d;
        if(b<0) a=-a, b=-b;
        return (*this);
    }
};

int main(){
    int a, b, c;
    cin>>a>>b>>c;
    sieve(sqrt(a)+1);

    cout<<"Sieve:"<<primes<<endl;
    cout<<"Is it prime? "<<isPrime(a)<<endl;
    cout<<"Prime factors:"<<primeFactors(a)<<endl;
    cout<<"Relatively primes: "<<coprimes(a)<<endl;
    cout<<"Is it Carmichael? "<<carmichael(a)<<endl;
    cout<<"Trailing zeros: "<<zeros(a,b)<<endl;
    cout<<"GCD: "<<gcd(a,b)<<endl;
    cout<<"LCM: "<<lcm(a,b)<<endl;
    cout<<"Diophantine: "<<diophantine(a,b,c)<<endl;
    //cout<<"CRT: "<<CRT(cngr)<<endl;
}
